use strict;
use warnings;
package App::AllMyChangesUtils;
$App::AllMyChangesUtils::VERSION = '1.0.5';
# ABSTRACT: utils for site https://allmychanges.com


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::AllMyChangesUtils - utils for site https://allmychanges.com

=head1 VERSION

version 1.0.5

=head1 DESCRIPTION

Several scripts that help loading data to the site L<https://allmychanges.com>

=head1 AUTHOR

Ivan Bessarabov <ivan@bessarabov.ru>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Ivan Bessarabov.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
